pub struct NdarrayAdapter<U, O> { /* private fields */ }Expand description
A wrapper implementing the audioadapter traits for a two-dimensional
ndarray array.
The axis order O records whether the array is channel-major
(ChannelsFrames) or frame-major (FramesChannels).
Implementations
Sourceimpl<S> NdarrayAdapter<ArrayBase<S, Ix2>, ChannelsFrames>where
S: Data,
impl<S> NdarrayAdapter<ArrayBase<S, Ix2>, ChannelsFrames>where
S: Data,
Sourcepub fn new_channels_frames(array: ArrayBase<S, Ix2>) -> Self
pub fn new_channels_frames(array: ArrayBase<S, Ix2>) -> Self
Wrap an array shaped (channels, frames).
Sourceimpl<S> NdarrayAdapter<ArrayBase<S, Ix2>, FramesChannels>where
S: Data,
impl<S> NdarrayAdapter<ArrayBase<S, Ix2>, FramesChannels>where
S: Data,
Sourcepub fn new_frames_channels(array: ArrayBase<S, Ix2>) -> Self
pub fn new_frames_channels(array: ArrayBase<S, Ix2>) -> Self
Wrap an array shaped (frames, channels).
Sourceimpl<U, O> NdarrayAdapter<U, O>
impl<U, O> NdarrayAdapter<U, O>
Sourcepub fn into_inner(self) -> U
pub fn into_inner(self) -> U
Consume the adapter and return the wrapped array.